CheckIns class

Implemented types

Constructors

CheckIns({required String id, required String userId, String? categoryId, String? status, required Map<String, dynamic> questions, String? summary, String? insight, String? brief, int? level, DateTime? createdAt, DateTime? completedAt})
const
CheckIns.fromJson(Map<String, dynamic> jsonn)
factory

Properties

brief String?
final
categoryId String?
final
completedAt DateTime?
final
createdAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
insight String?
final
level int?
final
questions Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final
summary String?
final
userId String
final

Methods

copyWith({Object? id = _unset, Object? userId = _unset, Object? categoryId = _unset, Object? status = _unset, Object? questions = _unset, Object? summary = _unset, Object? insight = _unset, Object? brief = _unset, Object? level = _unset, Object? createdAt = _unset, Object? completedAt = _unset}) CheckIns
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

c_brief String
no setter
c_categoryId String
no setter
c_completedAt String
no setter
c_createdAt String
no setter
c_id String
no setter
c_insight String
no setter
c_level String
no setter
c_questions String
no setter
c_status String
no setter
c_summary String
no setter
c_userId String
no setter
table_name String
no setter

Static Methods

converter(List<Map<String, dynamic>> data) List<CheckIns>
converterSingle(Map<String, dynamic> data) CheckIns
insert({String? id, required String userId, String? categoryId, String? status, required Map<String, dynamic> questions, String? summary, String? insight, String? brief, int? level, DateTime? createdAt, DateTime? completedAt}) Map<String, dynamic>
New({String? id, String? userId, String? categoryId, String? status, Map<String, dynamic>? questions, String? summary, String? insight, String? brief, int? level, DateTime? createdAt, DateTime? completedAt}) Object
update({String? id, String? userId, String? categoryId, String? status, Map<String, dynamic>? questions, String? summary, String? insight, String? brief, int? level, DateTime? createdAt, DateTime? completedAt}) Map<String, dynamic>