HealthCards class

Implemented types

Constructors

HealthCards({required String id, required String userId, String? categoryId, String? checkinId, required int type, required String title, required String content, int? importance, bool? isChecked, DateTime? expiresAt, DateTime? createdAt, String? recommendationId, String? insight, String? action, String? why, bool? isActive, num? relevance, DateTime? viewedAt, DateTime? dismissedAt})
const
HealthCards.fromJson(Map<String, dynamic> jsonn)
factory

Properties

action String?
final
categoryId String?
final
checkinId String?
final
content String
final
createdAt DateTime?
final
dismissedAt DateTime?
final
expiresAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
importance int?
final
insight String?
final
isActive bool?
final
isChecked bool?
final
recommendationId String?
final
relevance num?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
type int
final
userId String
final
viewedAt DateTime?
final
why String?
final

Methods

copyWith({Object? id = _unset, Object? userId = _unset, Object? categoryId = _unset, Object? checkinId = _unset, Object? type = _unset, Object? title = _unset, Object? content = _unset, Object? importance = _unset, Object? isChecked = _unset, Object? expiresAt = _unset, Object? createdAt = _unset, Object? recommendationId = _unset, Object? insight = _unset, Object? action = _unset, Object? why = _unset, Object? isActive = _unset, Object? relevance = _unset, Object? viewedAt = _unset, Object? dismissedAt = _unset}) HealthCards
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

c_action String
no setter
c_categoryId String
no setter
c_checkinId String
no setter
c_content String
no setter
c_createdAt String
no setter
c_dismissedAt String
no setter
c_expiresAt String
no setter
c_id String
no setter
c_importance String
no setter
c_insight String
no setter
c_isActive String
no setter
c_isChecked String
no setter
c_recommendationId String
no setter
c_relevance String
no setter
c_title String
no setter
c_type String
no setter
c_userId String
no setter
c_viewedAt String
no setter
c_why String
no setter
table_name String
no setter

Static Methods

converter(List<Map<String, dynamic>> data) List<HealthCards>
converterSingle(Map<String, dynamic> data) HealthCards
insert({String? id, required String userId, String? categoryId, String? checkinId, required int type, required String title, required String content, int? importance, bool? isChecked, DateTime? expiresAt, DateTime? createdAt, String? recommendationId, String? insight, String? action, String? why, bool? isActive, num? relevance, DateTime? viewedAt, DateTime? dismissedAt}) Map<String, dynamic>
New({String? id, String? userId, String? categoryId, String? checkinId, int? type, String? title, String? content, int? importance, bool? isChecked, DateTime? expiresAt, DateTime? createdAt, String? recommendationId, String? insight, String? action, String? why, bool? isActive, num? relevance, DateTime? viewedAt, DateTime? dismissedAt}) Object
update({String? id, String? userId, String? categoryId, String? checkinId, int? type, String? title, String? content, int? importance, bool? isChecked, DateTime? expiresAt, DateTime? createdAt, String? recommendationId, String? insight, String? action, String? why, bool? isActive, num? relevance, DateTime? viewedAt, DateTime? dismissedAt}) Map<String, dynamic>