RecommendationRequest class

Constructors

RecommendationRequest({int? count, String? category_id, dynamic context_type})
RecommendationRequest.fromJson(Map<String, dynamic> json)
factory

Properties

category_id String?
final
context_type → dynamic
final
count int?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited