CheckinTemplates class
- Implemented types
Constructors
Properties
- categoryId → String
-
final
- createdAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isActive → bool?
-
final
-
questions
→ Map<
String, dynamic> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → DateTime
-
final
Methods
-
copyWith(
{Object? id = _unset, Object? categoryId = _unset, Object? questions = _unset, Object? isActive = _unset, Object? createdAt = _unset, Object? updatedAt = _unset}) → CheckinTemplates -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- c_categoryId → String
-
no setter
- c_createdAt → String
-
no setter
- c_id → String
-
no setter
- c_isActive → String
-
no setter
- c_questions → String
-
no setter
- c_updatedAt → String
-
no setter
- table_name → String
-
no setter
Static Methods
-
converter(
List< Map< data) → List<String, dynamic> >CheckinTemplates> -
converterSingle(
Map< String, dynamic> data) → CheckinTemplates -
insert(
{String? id, required String categoryId, required Map< String, dynamic> questions, bool? isActive, DateTime? createdAt, DateTime? updatedAt}) → Map<String, dynamic> -
New(
{String? id, String? categoryId, Map< String, dynamic> ? questions, bool? isActive, DateTime? createdAt, DateTime? updatedAt}) → Object -
update(
{String? id, String? categoryId, Map< String, dynamic> ? questions, bool? isActive, DateTime? createdAt, DateTime? updatedAt}) → Map<String, dynamic>