HealthCards class
Constructors
-
HealthCards({required String id, required String userId, String? categoryId, String? checkinId, required int type, required String title, required String content, int? importance, bool? isChecked, DateTime? expiresAt, DateTime? createdAt, String? recommendationId, String? insight, String? action, String? why, bool? isActive, num? relevance, DateTime? viewedAt, DateTime? dismissedAt})
-
const
-
HealthCards.fromJson(Map<String, dynamic> jsonn)
-
factory
Methods
-
copyWith({Object? id = _unset, Object? userId = _unset, Object? categoryId = _unset, Object? checkinId = _unset, Object? type = _unset, Object? title = _unset, Object? content = _unset, Object? importance = _unset, Object? isChecked = _unset, Object? expiresAt = _unset, Object? createdAt = _unset, Object? recommendationId = _unset, Object? insight = _unset, Object? action = _unset, Object? why = _unset, Object? isActive = _unset, Object? relevance = _unset, Object? viewedAt = _unset, Object? dismissedAt = _unset})
→ HealthCards
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
converter(List<Map<String, dynamic>> data)
→ List<HealthCards>
-
-
converterSingle(Map<String, dynamic> data)
→ HealthCards
-
-
insert({String? id, required String userId, String? categoryId, String? checkinId, required int type, required String title, required String content, int? importance, bool? isChecked, DateTime? expiresAt, DateTime? createdAt, String? recommendationId, String? insight, String? action, String? why, bool? isActive, num? relevance, DateTime? viewedAt, DateTime? dismissedAt})
→ Map<String, dynamic>
-
-
New({String? id, String? userId, String? categoryId, String? checkinId, int? type, String? title, String? content, int? importance, bool? isChecked, DateTime? expiresAt, DateTime? createdAt, String? recommendationId, String? insight, String? action, String? why, bool? isActive, num? relevance, DateTime? viewedAt, DateTime? dismissedAt})
→ Object
-
-
update({String? id, String? userId, String? categoryId, String? checkinId, int? type, String? title, String? content, int? importance, bool? isChecked, DateTime? expiresAt, DateTime? createdAt, String? recommendationId, String? insight, String? action, String? why, bool? isActive, num? relevance, DateTime? viewedAt, DateTime? dismissedAt})
→ Map<String, dynamic>
-