UserAppVersions class
- Implemented types
Constructors
Properties
- deviceModel → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- installedAt → DateTime?
-
final
- lastOpenedAt → DateTime?
-
final
- osVersion → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String
-
final
- versionId → String
-
final
Methods
-
copyWith(
{Object? id = _unset, Object? userId = _unset, Object? versionId = _unset, Object? deviceModel = _unset, Object? osVersion = _unset, Object? installedAt = _unset, Object? lastOpenedAt = _unset}) → UserAppVersions -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- c_deviceModel → String
-
no setter
- c_id → String
-
no setter
- c_installedAt → String
-
no setter
- c_lastOpenedAt → String
-
no setter
- c_osVersion → String
-
no setter
- c_userId → String
-
no setter
- c_versionId → String
-
no setter
- table_name → String
-
no setter
Static Methods
-
converter(
List< Map< data) → List<String, dynamic> >UserAppVersions> -
converterSingle(
Map< String, dynamic> data) → UserAppVersions -
insert(
{String? id, required String userId, required String versionId, String? deviceModel, String? osVersion, DateTime? installedAt, DateTime? lastOpenedAt}) → Map< String, dynamic> -
New(
{String? id, String? userId, String? versionId, String? deviceModel, String? osVersion, DateTime? installedAt, DateTime? lastOpenedAt}) → Object -
update(
{String? id, String? userId, String? versionId, String? deviceModel, String? osVersion, DateTime? installedAt, DateTime? lastOpenedAt}) → Map< String, dynamic>